AtemCommand class abstract

Internal base class for AtemCommand.

Implementers

Constructors

AtemCommand()
const
AtemCommand.from(String code, Uint8List buildData())
Creates a command from a code and typed data builder.
factory

Properties

code String
4-character command code (e.g., 'PrgI', 'PrvI', 'CTlC').
no setter
data Uint8List
Command payload data.
no setter
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toBytes() Uint8List
Serializes the command to bytes.
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited