KeyPropertiesBaseCommand class

Key properties base command.

Inheritance

Constructors

KeyPropertiesBaseCommand({required int meIndex, required int keyerIndex, int? keyType, bool? enabled, bool? flyEnabled, int? fillSource, int? keySource, bool? maskEnabled, int? maskTop, int? maskBottom, int? maskLeft, int? maskRight})
const

Properties

code String
4-character command code (e.g., 'PrgI', 'PrvI', 'CTlC').
no setteroverride
data Uint8List
Command payload data.
no setteroverride
enabled bool?
final
fillSource int?
final
flyEnabled bool?
final
hashCode int
The hash code for this object.
no setterinherited
keyerIndex int
final
keySource int?
final
keyType int?
final
maskBottom int?
final
maskEnabled bool?
final
maskLeft int?
final
maskRight int?
final
maskTop int?
final
meIndex int
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

build() Uint8List
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toBytes() Uint8List
Serializes the command to bytes.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited