ProgramInputCommand class

Program input command (CPgI).

Inheritance

Constructors

ProgramInputCommand({required int meIndex, required int source})
const

Properties

code String
4-character command code (e.g., 'PrgI', 'PrvI', 'CTlC').
no setteroverride
data Uint8List
Command payload data.
no setteroverride
hashCode int
The hash code for this object.
no setterinherited
meIndex int
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
source int
final

Methods

build() Uint8List
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toBytes() Uint8List
Serializes the command to bytes.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited