AtemConnection class

Main ATEM connection class.

Constructors

AtemConnection({AtemConnectionConfig? config})

Properties

events Stream<AtemEvent>
no setter
hashCode int
The hash code for this object.
no setterinherited
isConnected bool
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
state AtemState
no setter

Methods

autoTransition(int meIndex) Future<void>
Performs an auto transition on an ME.
connect() Future<void>
Connects to the ATEM switcher.
cut(int meIndex) Future<void>
Performs a cut on an ME.
disconnect() Future<void>
Disconnects from the ATEM switcher.
executeFadeToBlack(int meIndex, bool onAir) Future<void>
Executes fade to black.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
sendCommand(AtemCommand command, {bool reliable = true}) Future<AtemPacket?>
Sends a command to the switcher.
sendCommands(List<AtemCommand> commands, {bool reliable = true}) Future<void>
Sends multiple commands in a single packet.
sendRaw(Uint8List data, {bool reliable = true}) → void
Sends raw data.
sendTimeRequest() → void
Requests a time (keepalive).
setAuxSource(int auxIndex, int source) Future<void>
Sets aux output source.
setColorGenerator(int index, {int? hue, int? saturation, int? luminance}) Future<void>
Sets color generator.
setFadeToBlack(int meIndex, {int? rate}) Future<void>
Sets fade to black.
setKeyOnAir(int meIndex, int keyerIndex, bool onAir) Future<void>
Sets key on air state.
setKeyProperties({required int meIndex, required int keyerIndex, int? keyType, bool? enabled, bool? flyEnabled, int? fillSource, int? keySource, bool? maskEnabled, int? maskTop, int? maskBottom, int? maskLeft, int? maskRight}) Future<void>
Sets key properties.
setPreviewInput(int meIndex, int source) Future<void>
Sets preview input for an ME.
setProgramInput(int meIndex, int source) Future<void>
Sets program input for an ME.
setTransition({required int meIndex, int? type, int? duration, int? style}) Future<void>
Sets transition settings.
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited