AtemConnectionConfig class

ATEM connection configuration.

Constructors

AtemConnectionConfig({String host = '192.168.1.10', int port = 9910, Duration timeout = const Duration(seconds: 5), Duration keepAliveInterval = const Duration(seconds: 1), bool reconnect = false, Duration reconnectInterval = const Duration(seconds: 5)})
const

Properties

hashCode int
The hash code for this object.
no setterinherited
host String
final
keepAliveInterval Duration
final
port int
final
reconnect bool
final
reconnectInterval Duration
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
timeout Duration
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited