AudioLevel class

Audio level data.

Constructors

AudioLevel({required double left, required double right, required double leftPeak, required double rightPeak})
const

Properties

hashCode int
The hash code for this object.
no setterinherited
left double
final
leftPeak double
final
final
rightPeak double
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited