AudioMeterLevelsField class

Audio meter levels (AMLv).

Inheritance

Constructors

AudioMeterLevelsField(Uint8List rawData)

Properties

channelCount int
latefinal
code String
The 4-character field code.
no setteroverride
hashCode int
The hash code for this object.
no setterinherited
inputs Map<int, AudioLevel>
latefinal
levelOffset int
latefinal
master List<AudioLevel>
latefinal
monitor List<AudioLevel>
latefinal
rawData Uint8List
Raw field data.
finalinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited