CameraControlDataPacketField class

Camera control data packet (CCdP).

Inheritance

Constructors

CameraControlDataPacketField(Uint8List rawData)

Properties

category int
latefinal
code String
The 4-character field code.
no setteroverride
data List<int>
latefinal
dataType int
latefinal
destination int
latefinal
hashCode int
The hash code for this object.
no setterinherited
parameter int
latefinal
rawData Uint8List
Raw field data.
finalinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited