FadeToBlackStateField class

Fade to black state (FtbS).

Inheritance

Constructors

FadeToBlackStateField(Uint8List rawData)

Properties

active bool
latefinal
code String
The 4-character field code.
no setteroverride
fullyBlack bool
latefinal
hashCode int
The hash code for this object.
no setterinherited
meIndex int
latefinal
position int
latefinal
positionNormalized double
no setter
rate int
latefinal
rawData Uint8List
Raw field data.
finalinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited