FairlightMeterLevelsField class

Fairlight meter levels (FMLv).

Inheritance

Constructors

FairlightMeterLevelsField(Uint8List rawData)

Properties

code String
The 4-character field code.
no setteroverride
compressorGr double
latefinal
expanderGr double
latefinal
faderLeft double
latefinal
faderPeakLeft double
latefinal
faderPeakRight double
latefinal
faderRight double
latefinal
hashCode int
The hash code for this object.
no setterinherited
inputLeft double
latefinal
inputPeakLeft double
latefinal
inputPeakRight double
latefinal
inputRight double
latefinal
limiterGr double
latefinal
outputLeft double
latefinal
outputPeakLeft double
latefinal
outputPeakRight double
latefinal
outputRight double
latefinal
rawData Uint8List
Raw field data.
finalinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
source int
latefinal
stripId String
no setter
subChannel int
latefinal

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited