FairlightPropertiesField class

Fairlight properties (FMPP).

Inheritance

Constructors

FairlightPropertiesField(Uint8List rawData)

Properties

bitDepth int
latefinal
channels int
latefinal
code String
The 4-character field code.
no setteroverride
frameRate int
latefinal
hashCode int
The hash code for this object.
no setterinherited
rawData Uint8List
Raw field data.
finalinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
sampleRate int
latefinal

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited