FairlightStripPropertiesField class

Fairlight strip properties (FASP).

Inheritance

Properties

balance int
latefinal
code String
The 4-character field code.
no setteroverride
faderGain int
latefinal
faderMute bool
latefinal
gain int
latefinal
hashCode int
The hash code for this object.
no setterinherited
mixOption int
latefinal
mute bool
latefinal
rawData Uint8List
Raw field data.
finalinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
solo bool
latefinal
stripId int
latefinal
stripType FairlightStripType
no setter
type int
latefinal

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited