FirmwareVersionField class

Firmware version field (_ver).

Inheritance

Constructors

FirmwareVersionField(Uint8List rawData)

Properties

build int
latefinal
code String
The 4-character field code.
no setteroverride
hashCode int
The hash code for this object.
no setterinherited
major int
latefinal
minor int
latefinal
patch int
latefinal
rawData Uint8List
Raw field data.
finalinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
versionString String
no setter

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited