InputPropertiesField class

Input properties (InPr).

Inheritance

Constructors

InputPropertiesField(Uint8List rawData)

Properties

code String
The 4-character field code.
no setteroverride
hashCode int
The hash code for this object.
no setterinherited
hasLongName bool
no setter
hasPortType bool
no setter
hasShortName bool
no setter
longName String
latefinal
mask int
latefinal
portType int
latefinal
rawData Uint8List
Raw field data.
finalinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
shortName String
latefinal
sourceIndex int
latefinal

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited