KeyPropertiesBaseField class

Key properties base (KeBP).

Inheritance

Constructors

KeyPropertiesBaseField(Uint8List rawData)

Properties

code String
The 4-character field code.
no setteroverride
enabled bool
latefinal
fillSource int
latefinal
flyEnabled bool
latefinal
hashCode int
The hash code for this object.
no setterinherited
keyerIndex int
latefinal
keySource int
latefinal
keyType int
latefinal
maskBottom int
latefinal
maskEnabled bool
latefinal
maskLeft int
latefinal
maskRight int
latefinal
maskTop int
latefinal
meIndex int
latefinal
rawData Uint8List
Raw field data.
finalinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
type KeyType
no setter

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited