MacroPlayStatusField class

Macro play status (MRPr).

Inheritance

Constructors

MacroPlayStatusField(Uint8List rawData)

Properties

atEnd bool
latefinal
code String
The 4-character field code.
no setteroverride
hashCode int
The hash code for this object.
no setterinherited
index int
latefinal
loop bool
latefinal
playing bool
latefinal
rawData Uint8List
Raw field data.
finalinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited