MultiviewerInputField class

Multiviewer input (MvIn).

Inheritance

Constructors

MultiviewerInputField(Uint8List rawData)

Properties

code String
The 4-character field code.
no setteroverride
hashCode int
The hash code for this object.
no setterinherited
index int
latefinal
rawData Uint8List
Raw field data.
finalinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
safeAreaSupported bool
latefinal
source int
latefinal
vuSupported bool
latefinal
window int
latefinal

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited