MultiviewerPropertiesField class

Multiviewer properties (MvPr).

Inheritance

Constructors

MultiviewerPropertiesField(Uint8List rawData)

Properties

bottomLeftSmall bool
no setter
bottomRightSmall bool
no setter
code String
The 4-character field code.
no setteroverride
flip bool
latefinal
hashCode int
The hash code for this object.
no setterinherited
index int
latefinal
layout int
latefinal
rawData Uint8List
Raw field data.
finalinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
topLeftSmall bool
no setter
topRightSmall bool
no setter
u1 int
latefinal

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited