RecordingDiskField class

Recording disk (RTMD).

Inheritance

Constructors

RecordingDiskField(Uint8List rawData)

Properties

code String
The 4-character field code.
no setteroverride
hashCode int
The hash code for this object.
no setterinherited
index int
latefinal
isAttached bool
no setter
isDeleted bool
no setter
isReady bool
no setter
isRecording bool
no setter
rawData Uint8List
Raw field data.
finalinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
status int
latefinal
timeAvailable int
latefinal
volumeName String
latefinal

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited