RecordingSettingsField class

Recording settings (RMSu).

Inheritance

Constructors

RecordingSettingsField(Uint8List rawData)

Properties

code String
The 4-character field code.
no setteroverride
disk1 int
latefinal
disk2 int
latefinal
filename String
latefinal
hashCode int
The hash code for this object.
no setterinherited
rawData Uint8List
Raw field data.
finalinherited
recordInCameras bool
latefinal
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited