StreamingState enum

Streaming state enum.

Inheritance
Available extensions

Values

unknown → const StreamingState
const StreamingState(-1)
idle → const StreamingState
const StreamingState(0)
nothing → const StreamingState
const StreamingState(1)
connecting → const StreamingState
const StreamingState(2)
onAir → const StreamingState
const StreamingState(4)
stopping → const StreamingState
const StreamingState(22)

Properties

hashCode int
The hash code for this object.
no setterinherited
index int
A numeric identifier for the enumerated value.
no setterinherited
name String

Available on Enum, provided by the EnumName extension

The name of the enum value.
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
value int
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

fromValue(int value) StreamingState

Constants

values → const List<StreamingState>
A constant List of the values in this enum, in order of their declaration.