SuperSourceBoxPropertiesField class

SuperSource box properties (SSBP).

Inheritance

Properties

box int
latefinal
code String
The 4-character field code.
no setteroverride
enabled bool
latefinal
hashCode int
The hash code for this object.
no setterinherited
index int
latefinal
maskBottom int
latefinal
masked bool
latefinal
maskLeft int
latefinal
maskRight int
latefinal
maskTop int
latefinal
rawData Uint8List
Raw field data.
finalinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
size int
latefinal
source int
latefinal
x int
latefinal
y int
latefinal

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited