TopologyField class

Topology field (_top).

Inheritance

Constructors

TopologyField(Uint8List rawData)

Properties

audioMixerChannels int
latefinal
auxCount int
latefinal
code String
The 4-character field code.
no setteroverride
dskCount int
latefinal
hashCode int
The hash code for this object.
no setterinherited
keyerCount int
latefinal
meCount int
latefinal
mediaPlayerCount int
latefinal
multiviewerCount int
latefinal
rawData Uint8List
Raw field data.
finalinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
superSourceCount int
latefinal

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited