TransitionSettingsField class

Transition settings (TrSS).

Inheritance

Constructors

TransitionSettingsField(Uint8List rawData)

Properties

code String
The 4-character field code.
no setteroverride
hashCode int
The hash code for this object.
no setterinherited
meIndex int
latefinal
nextTransition int
latefinal
rate int
latefinal
rawData Uint8List
Raw field data.
finalinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
style TransitionStyle
no setter
transitionStyle int
latefinal
transitionType int
latefinal
type TransitionType
no setter

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited