TransitionStingerField class

Stinger transition properties (TStP).

Inheritance

Constructors

TransitionStingerField(Uint8List rawData)

Properties

clip int
latefinal
code String
The 4-character field code.
no setteroverride
gain int
latefinal
hashCode int
The hash code for this object.
no setterinherited
invertKey int
latefinal
meIndex int
latefinal
mixRate int
latefinal
preMultiplied int
latefinal
rate int
latefinal
rawData Uint8List
Raw field data.
finalinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
triggerPoint int
latefinal

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited