UsbAudioFunctionField class

USB audio function (UAFn).

Inheritance

Constructors

UsbAudioFunctionField(Uint8List rawData)

Properties

code String
The 4-character field code.
no setteroverride
function int
latefinal
hashCode int
The hash code for this object.
no setterinherited
mode UsbAudioMode
no setter
rawData Uint8List
Raw field data.
finalinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
u1 int
latefinal

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited