AtemPacketFlags class
ATEM UDP protocol flags.
Constructors
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Methods
-
isAck(
int flags) → bool -
isReliable(
int flags) → bool -
isRequestRetransmission(
int flags) → bool -
isRetransmission(
int flags) → bool -
isSyn(
int flags) → bool
Constants
- ack → const int
- reliable → const int
- requestRetransmission → const int
- retransmission → const int
- syn → const int