AudioStripState class
Audio strip state.
Constructors
- AudioStripState({int index = 0, FairlightStripType type = FairlightStripType.audioInput, int mixOption = 0, int gain = 0, int balance = 0, bool mute = false, bool solo = false, int faderGain = 0, bool faderMute = false})
Properties
- balance → int
-
final
- faderGain → int
-
final
- faderMute → bool
-
final
- gain → int
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- index → int
-
final
- mixOption → int
-
final
- mute → bool
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- solo → bool
-
final
- type → FairlightStripType
-
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited