FairlightMasterState class

Fairlight master state.

Constructors

FairlightMasterState({int index = 0, double inputLeft = -60.0, double inputRight = -60.0, double outputLeft = -60.0, double outputRight = -60.0, double faderLeft = -60.0, double faderRight = -60.0})

Properties

faderLeft double
final
faderRight double
final
hashCode int
The hash code for this object.
no setterinherited
index int
final
inputLeft double
final
inputRight double
final
outputLeft double
final
outputRight double
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited