FairlightStripState class

Fairlight strip state.

Constructors

FairlightStripState({String stripId = '', int index = 0, int subChannel = 0, FairlightStripType type = FairlightStripType.audioInput, double gain = 0.0, double balance = 0.0, bool mute = false, bool solo = false, double faderGain = 0.0, bool faderMute = false, double inputLeft = -60.0, double inputRight = -60.0, double outputLeft = -60.0, double outputRight = -60.0, double faderLeft = -60.0, double faderRight = -60.0})

Properties

balance double
final
faderGain double
final
faderLeft double
final
faderMute bool
final
faderRight double
final
gain double
final
hashCode int
The hash code for this object.
no setterinherited
index int
final
inputLeft double
final
inputRight double
final
mute bool
final
outputLeft double
final
outputRight double
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
solo bool
final
stripId String
final
subChannel int
final
type FairlightStripType
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited