MediaPlayerState class

Media player state.

Constructors

MediaPlayerState({int index = 0, int clipIndex = 0, bool playing = false, bool atStart = false, bool loop = false, String clipName = '', int frames = 0, int frameRate = 0, int width = 0, int height = 0, int source = 0, int audioSource = 0, int audioGain = 0, int audioBalance = 0, bool audioMute = false})

Properties

atStart bool
final
audioBalance int
final
audioGain int
final
audioMute bool
final
audioSource int
final
clipIndex int
final
clipName String
final
frameRate int
final
frames int
final
hashCode int
The hash code for this object.
no setterinherited
height int
final
index int
final
loop bool
final
playing bool
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
source int
final
width int
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited