MultiviewerState class

Multiviewer state.

Constructors

MultiviewerState({int index = 0, int layout = 0, bool flip = false, Map<int, MultiviewerWindow> windows = const {}})

Properties

flip bool
final
hashCode int
The hash code for this object.
no setterinherited
index int
final
layout int
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
windows Map<int, MultiviewerWindow>
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited