MultiviewerWindow class

Multiviewer window.

Constructors

MultiviewerWindow({int index = 0, int source = 0, bool vuSupported = false, bool safeAreaSupported = false, bool vuEnabled = false, bool safeAreaEnabled = false})

Properties

hashCode int
The hash code for this object.
no setterinherited
index int
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
safeAreaEnabled bool
final
safeAreaSupported bool
final
source int
final
vuEnabled bool
final
vuSupported bool
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited