StreamingState class

Streaming state.

Constructors

StreamingState({StreamingStateEnum state = StreamingStateEnum.idle, int bitrate = 0, int cacheUsed = 0, String serviceName = '', String serviceUrl = '', int minBitrate = 0, int maxBitrate = 0})

Properties

bitrate int
final
cacheUsed int
final
hashCode int
The hash code for this object.
no setterinherited
maxBitrate int
final
minBitrate int
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
serviceName String
final
serviceUrl String
final
state StreamingStateEnum
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited