Topology class

Topology info.

Constructors

Topology({int meCount = 0, int keyerCount = 0, int dskCount = 0, int auxCount = 0, int mediaPlayerCount = 0, int superSourceCount = 0, int multiviewerCount = 0, int audioMixerChannels = 0})

Properties

audioMixerChannels int
final
auxCount int
final
dskCount int
final
hashCode int
The hash code for this object.
no setterinherited
keyerCount int
final
meCount int
final
mediaPlayerCount int
final
multiviewerCount int
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
superSourceCount int
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited