HyperDeck class

Backwards-compatible static facade for the original package API.

Constructors

HyperDeck()
Creates the backwards-compatible static facade.

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Properties

clipId String?
getter/setter pair
deviceName String?
getter/setter pair
deviceStatus String?
getter/setter pair
displayTimecode String?
getter/setter pair
hyperDeckIP String
getter/setter pair
inputVideoFormat String?
getter/setter pair
loop String?
getter/setter pair
port int
getter/setter pair
responseData String?
getter/setter pair
slotId String?
getter/setter pair
socket Socket?
getter/setter pair
speed String?
getter/setter pair
status bool
getter/setter pair
timecode String?
getter/setter pair
timeline String?
getter/setter pair
videoFormat String?
getter/setter pair

Static Methods

close() Future<void>
command(String name, [Map<String, Object?> parameters = const {}]) Future<HyperDeckResponse>
configure(Map<String, Object?> settings) Future<HyperDeckResponse>
connect() Future<void>
dataHandler(List<int> data) → void
deviceInfo() Future<HyperDeckResponse>
doneHandler() → void
errorHandler(Object error, StackTrace stackTrace) → void
goTo(Map<String, Object?> position) Future<HyperDeckResponse>
info() Future<HyperDeckResponse>
multilineCommand(String name, Map<String, Object?> parameters) Future<HyperDeckResponse>
notify(Map<String, bool> settings) Future<HyperDeckResponse>
play({int? speed, bool? loop, bool? singleClip, int? clipId}) Future<HyperDeckResponse>
record([String? name]) Future<HyperDeckResponse>
selectSlot({int? slotId, String? device, String? videoFormat}) Future<HyperDeckResponse>
send(String rawCommand) Future<HyperDeckResponse>
stopRecording() Future<HyperDeckResponse>