HyperDeckResponse class

A parsed Ethernet protocol response. Responses with status 500-599 are unsolicited device notifications.

Constructors

HyperDeckResponse(int code, String message, Map<String, String> values, String raw)

Properties

code int
final
hashCode int
The hash code for this object.
no setterinherited
isNotification bool
no setter
isSuccess bool
no setter
message String
final
raw String
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
values Map<String, String>
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited