HyperDeckEventSocket class

Client for the REST API notification WebSocket. The device replies to subscribe, unsubscribe, listSubscriptions and listProperties commands on messages, and emits propertyValueChanged events on the same stream.

Properties

hashCode int
The hash code for this object.
no setterinherited
messages Stream<Object?>
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

close([int? code, String? reason]) Future<void>
listProperties({int? id}) → void
listSubscriptions({int? id}) → void
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
send(String action, {List<String>? properties, Object? values, int? id}) → void
subscribe(List<String> properties, {int? id}) → void
toString() String
A string representation of this object.
inherited
unsubscribe(List<String> properties, {int? id}) → void

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

connect(Uri baseUri, {String path = '/event'}) Future<HyperDeckEventSocket>