web_presenter/web_presenter library

Classes

StreamingConfig
StreamingCredentials
StreamingProfile
StreamingServer
StreamingService
StreamingXmlDocument
Builders for the Blackmagic Streaming XML file format.
WebPresenterBlock
A status block received from a Blackmagic Streaming Encoder.
WebPresenterConnection
TCP client for every block in the Blackmagic Streaming Ethernet Protocol.
WebPresenterEventSocket
Client for the Streaming Encoder REST notification WebSocket.
WebPresenterRestClient
REST client for every endpoint in the Streaming Encoder Control REST API.
WebPresenterRestResponse

Exceptions / Errors

WebPresenterProtocolException
Thrown when the device rejects a TCP block request with NACK.
WebPresenterRestException