updates property
Stream<WebPresenterBlock>
get
updates
All state blocks, including the initial device dump and later changes.
Implementation
Stream<WebPresenterBlock> get updates => _blocks.stream;
All state blocks, including the initial device dump and later changes.
Stream<WebPresenterBlock> get updates => _blocks.stream;