WebPresenterRestClient class

REST client for every endpoint in the Streaming Encoder Control REST API.

Constructors

WebPresenterRestClient(Uri deviceUri, {HttpClient? httpClient})

Properties

baseUri Uri
final
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

activeMonitorOutputAudioSource() Future<WebPresenterRestResponse>
activePlatform() Future<WebPresenterRestResponse>
close({bool force = false}) Future<void>
connectEvents({String path = '/event'}) Future<WebPresenterEventSocket>
Connects to the documented notification WebSocket.
customPlatform(String filename) Future<WebPresenterRestResponse>
customPlatforms() Future<WebPresenterRestResponse>
delete(String path) Future<WebPresenterRestResponse>
eventList() Future<WebPresenterRestResponse>
get(String path) Future<WebPresenterRestResponse>
isStreamActive() Future<WebPresenterRestResponse>
isStreamStopped() Future<WebPresenterRestResponse>
livestream() Future<WebPresenterRestResponse>
monitorOutputAudioSources() Future<WebPresenterRestResponse>
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
platform(String name) Future<WebPresenterRestResponse>
platforms() Future<WebPresenterRestResponse>
post(String path, [Object? body]) Future<WebPresenterRestResponse>
product() Future<WebPresenterRestResponse>
put(String path, [Object? body]) Future<WebPresenterRestResponse>
removeAllCustomPlatforms() Future<WebPresenterRestResponse>
removeCustomPlatform(String filename) Future<WebPresenterRestResponse>
request(String method, String path, {Object? body, String? contentType, Map<String, String>? headers}) Future<WebPresenterRestResponse>
setActivePlatform(Map<String, Object?> platform) Future<WebPresenterRestResponse>
setMonitorOutputAudioSource(String source) Future<WebPresenterRestResponse>
setVideoFormat(Map<String, Object?> format) Future<WebPresenterRestResponse>
startStream() Future<WebPresenterRestResponse>
stopStream() Future<WebPresenterRestResponse>
supportedVideoFormats() Future<WebPresenterRestResponse>
system() Future<WebPresenterRestResponse>
toString() String
A string representation of this object.
inherited
uploadCustomPlatform(String filename, String xml, {bool compact = true}) Future<WebPresenterRestResponse>
videoFormat() Future<WebPresenterRestResponse>

Operators

operator ==(Object other) bool
The equality operator.
inherited