StreamingServer class

Constructors

StreamingServer({required String name, required String url, String? group, Map<String, String> srtStreamIdExtensions = const <String, String>{}})

Properties

group String?
final
hashCode int
The hash code for this object.
no setterinherited
name String
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
srtStreamIdExtensions Map<String, String>
Key/value items written under srt-extensions / stream-id.
final
url String
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited