StreamingService class

Constructors

StreamingService({required String name, required List<StreamingProfile> profiles, List<StreamingServer> servers = const <StreamingServer>[], String? key, String? defaultProfile, StreamingCredentials? credentials, bool customizableUrl = false})

Properties

credentials StreamingCredentials?
final
customizableUrl bool
final
defaultProfile String?
final
hashCode int
The hash code for this object.
no setterinherited
key String?
final
name String
final
profiles List<StreamingProfile>
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
servers List<StreamingServer>
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited