StreamingXmlDocument class

Builders for the Blackmagic Streaming XML file format.

The generated XML can be uploaded with WebPresenterConnection.uploadStreamXml or WebPresenterRestClient.uploadCustomPlatform.

Constructors

StreamingXmlDocument({required List<StreamingService> services})

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
services List<StreamingService>
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
override
toXml({bool pretty = true}) String

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

compact(String xml) String
Removes blank lines because Streaming Encoder uploads treat blank lines as protocol block terminators.