AtemCommand class abstract
Internal base class for AtemCommand.
Constructors
- AtemCommand()
-
const
- AtemCommand.from(String code, Uint8List buildData())
-
Creates a command from a code and typed data builder.
factory
Properties
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toBytes(
) → Uint8List - Serializes the command to bytes.
-
toString(
) → String -
A string representation of this object.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited