AtemCommandBuilder class
Builder for ATEM command payloads.
Constructors
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
addBool(
bool value) → AtemCommandBuilder - Adds a boolean value (1 byte).
-
addBytes(
Uint8List bytes) → AtemCommandBuilder - Adds raw bytes.
-
addInt16(
int value) → AtemCommandBuilder - Adds an int16 value (big endian).
-
addInt32(
int value) → AtemCommandBuilder - Adds an int32 value (big endian).
-
addInt8(
int value) → AtemCommandBuilder - Adds an int8 value.
-
addPadding(
int count) → AtemCommandBuilder - Adds padding bytes.
-
addUint16(
int value) → AtemCommandBuilder - Adds a uint16 value (big endian).
-
addUint32(
int value) → AtemCommandBuilder - Adds a uint32 value (big endian).
-
addUint8(
int value) → AtemCommandBuilder - Adds a uint8 value.
-
build(
) → Uint8List - Builds the final Uint8List.
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited