ColorGeneratorCommand class
Color generator command.
- Inheritance
-
- Object
- AtemCommand
- ColorGeneratorCommand
Constructors
- ColorGeneratorCommand({required int index, int? hue, int? saturation, int? luminance})
-
const
Properties
- code → String
-
4-character command code (e.g., 'PrgI', 'PrvI', 'CTlC').
no setteroverride
- data → Uint8List
-
Command payload data.
no setteroverride
- hashCode → int
-
The hash code for this object.
no setterinherited
- hue → int?
-
final
- index → int
-
final
- luminance → int?
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- saturation → int?
-
final
Methods
-
build(
) → Uint8List -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toBytes(
) → Uint8List -
Serializes the command to bytes.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited