DskStateField class
DSK state (DskS).
Constructors
- DskStateField(Uint8List rawData)
Properties
- code → String
-
The 4-character field code.
no setteroverride
- dskIndex → int
-
latefinal
- hashCode → int
-
The hash code for this object.
no setterinherited
- onAir → bool
-
latefinal
- position → int
-
latefinal
- positionNormalized → double
-
no setter
- rawData → Uint8List
-
Raw field data.
finalinherited
- remainingFrames → int
-
latefinal
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- transitioning → bool
-
latefinal
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited