MediaPlayerFileInfoField class
Media player file info (MPfe).
Constructors
- MediaPlayerFileInfoField(Uint8List rawData)
Properties
- code → String
-
The 4-character field code.
no setteroverride
- format → int
-
latefinal
- formatString → String
-
latefinal
- frameRate → int
-
latefinal
- frames → int
-
latefinal
- hashCode → int
-
The hash code for this object.
no setterinherited
- height → int
-
latefinal
- index → int
-
latefinal
- loop → int
-
latefinal
- name → String
-
latefinal
- rawData → Uint8List
-
Raw field data.
finalinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- width → int
-
latefinal
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited