RecordingStatusField class
Recording status (RTMS).
Constructors
- RecordingStatusField(Uint8List rawData)
Properties
- code → String
-
The 4-character field code.
no setteroverride
- diskError → bool
-
no setter
- diskFull → bool
-
no setter
- diskUnformatted → bool
-
no setter
- hasDropped → bool
-
no setter
- hashCode → int
-
The hash code for this object.
no setterinherited
- isRecording → bool
-
no setter
- isStopping → bool
-
no setter
- rawData → Uint8List
-
Raw field data.
finalinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- status → int
-
latefinal
- timeAvailable → int
-
latefinal
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited