TransitionWipeField class
Wipe transition properties (TWpP).
Constructors
- TransitionWipeField(Uint8List rawData)
Properties
- borderBevel → int
-
latefinal
- borderBevelPosition → int
-
latefinal
- borderBevelSoftness → int
-
latefinal
- borderHue → int
-
latefinal
- borderInnerSoftness → int
-
latefinal
- borderInnerWidth → int
-
latefinal
- borderInput → int
-
latefinal
- borderLuma → int
-
latefinal
- borderOpacity → int
-
latefinal
- borderOuterSoftness → int
-
latefinal
- borderOuterWidth → int
-
latefinal
- borderSaturation → int
-
latefinal
- borderSize → int
-
latefinal
- code → String
-
The 4-character field code.
no setteroverride
- flipFlop → bool
-
latefinal
- hashCode → int
-
The hash code for this object.
no setterinherited
- meIndex → int
-
latefinal
- pattern → int
-
latefinal
- rate → int
-
latefinal
- rawData → Uint8List
-
Raw field data.
finalinherited
- reverse → bool
-
latefinal
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited