KeyerState class
Keyer state.
Constructors
- KeyerState({KeyType keyType = KeyType.off, bool enabled = false, bool flyEnabled = false, int fillSource = 0, int keySource = 0, bool maskEnabled = false, int maskTop = 0, int maskBottom = 0, int maskLeft = 0, int maskRight = 0, int dveSizeX = 10000, int dveSizeY = 10000, int dvePosX = 0, int dvePosY = 0, int dveRotation = 0, bool dveBorderEnabled = false, int dveBorderOuterWidth = 0, int dveBorderInnerWidth = 0, int dveBorderOuterSoftness = 0, int dveBorderInnerSoftness = 0, int dveBorderBevelSoftness = 0, int dveBorderBevelPosition = 0, int dveBorderOpacity = 0, int dveBorderHue = 0, int dveBorderSaturation = 0, int dveBorderLuma = 0, int dveLightAngle = 0, int dveLightAltitude = 0, bool lumaPremultiplied = false, int lumaClip = 0, int lumaGain = 1000, bool lumaInverted = false, int chromaForeground = 500, int chromaBackground = 500, int chromaKeyEdge = 500, int chromaSpill = 0, int chromaFlare = 0, int chromaBrightness = 0, int chromaContrast = 0, int chromaSaturation = 1000, int chromaRed = 0, int chromaGreen = 0, int chromaBlue = 0, int patternStyle = 0, int patternSize = 100, int patternSymmetry = 100, int patternSoftness = 0, bool patternInverted = false})
Properties
- chromaBackground → int
-
final
- chromaBlue → int
-
final
- chromaBrightness → int
-
final
- chromaContrast → int
-
final
- chromaFlare → int
-
final
- chromaForeground → int
-
final
- chromaGreen → int
-
final
- chromaKeyEdge → int
-
final
- chromaRed → int
-
final
- chromaSaturation → int
-
final
- chromaSpill → int
-
final
- dveBorderBevelPosition → int
-
final
- dveBorderBevelSoftness → int
-
final
- dveBorderEnabled → bool
-
final
- dveBorderHue → int
-
final
- dveBorderInnerSoftness → int
-
final
- dveBorderInnerWidth → int
-
final
- dveBorderLuma → int
-
final
- dveBorderOpacity → int
-
final
- dveBorderOuterSoftness → int
-
final
- dveBorderOuterWidth → int
-
final
- dveBorderSaturation → int
-
final
- dveLightAltitude → int
-
final
- dveLightAngle → int
-
final
- dvePosX → int
-
final
- dvePosY → int
-
final
- dveRotation → int
-
final
- dveSizeX → int
-
final
- dveSizeY → int
-
final
- enabled → bool
-
final
- fillSource → int
-
final
- flyEnabled → bool
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- isChroma → bool
-
no setter
- isDve → bool
-
no setter
- isLuma → bool
-
no setter
- isPattern → bool
-
no setter
- keySource → int
-
final
- keyType → KeyType
-
final
- lumaClip → int
-
final
- lumaGain → int
-
final
- lumaInverted → bool
-
final
- lumaPremultiplied → bool
-
final
- maskBottom → int
-
final
- maskEnabled → bool
-
final
- maskLeft → int
-
final
- maskRight → int
-
final
- maskTop → int
-
final
- onAir → bool
-
no setter
- patternInverted → bool
-
final
- patternSize → int
-
final
- patternSoftness → int
-
final
- patternStyle → int
-
final
- patternSymmetry → int
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
copyWith(
) → KeyerState -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited