RecordingState class
Recording state.
Constructors
Properties
- diskError → bool
-
final
- diskFull → bool
-
final
- diskUnformatted → bool
-
final
- droppedFrames → bool
-
final
- duration → String
-
no setter
- durationFrames → int
-
final
- durationHours → int
-
final
- durationMinutes → int
-
final
- durationSeconds → int
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- recording → bool
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- stopping → bool
-
final
- timeAvailable → int
-
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited