SuperSourceBox class
SuperSource box.
Constructors
Properties
- enabled → bool
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- index → int
-
final
- maskBottom → int
-
final
- masked → bool
-
final
- maskLeft → int
-
final
- maskRight → int
-
final
- maskTop → int
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- size → int
-
final
- source → int
-
final
- x → int
-
final
- y → int
-
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited