SuperSourceState class
SuperSource state.
Constructors
Properties
-
boxes
→ List<
SuperSourceBox> -
final
- clip → int
-
final
- fillSource → int
-
final
- gain → int
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- index → int
-
final
- inverted → bool
-
final
- keySource → int
-
final
- layer → int
-
final
- premultiplied → bool
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited