TransitionState class
Transition state.
Constructors
- TransitionState({int position = 0, bool preview = false, TransitionType type = TransitionType.mix, TransitionStyle style = TransitionStyle.mix, int rate = 50, int nextTransition = 0})
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- inTransition → bool
-
no setter
- nextTransition → int
-
final
- position → int
-
final
- positionNormalized → double
-
no setter
- preview → bool
-
final
- rate → int
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- style → TransitionStyle
-
final
- type → TransitionType
-
final
Methods
-
copyWith(
{int? position, bool? preview, TransitionType? type, TransitionStyle? style, int? rate, int? nextTransition}) → TransitionState -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited