HyperDeckCommand class
Builders for the line-oriented HyperDeck Ethernet protocol.
Every command listed in Blackmagic Design's Ethernet Protocol document can be sent with HyperDeckCommand.single or HyperDeckCommand.multiline. The named helpers below cover the commands that do not need parameters.
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Methods
Constants
- cacheInfo → const String
- clearPlayRange → const String
- clipInfo → const String
- clipsClear → const String
- clipsCount → const String
- clipsGet → const String
- clipsRebuild → const String
- commands → const String
- configuration → const String
- deviceInfo → const String
- diskList → const String
- dynamicRange → const String
- externalDriveList → const String
- externalDriveSelected → const String
- help → const String
- nasDeselect → const String
- nasDiscovered → const String
- nasList → const String
- nasSelected → const String
- notify → const String
- ping → const String
- play → const String
- playOnStartup → const String
- playOption → const String
- playRange → const String
- quit → const String
- record → const String
- recordSpill → const String
- remote → const String
- shortHelp → const String
- slateClips → const String
- slateLens → const String
- slateProject → const String
- slotInfo → const String
- slotUnblock → const String
- spillOrder → const String
- stop → const String
- transportInfo → const String
- uptime → const String