WebPresenterBlock class
A status block received from a Blackmagic Streaming Encoder.
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- isAcknowledgement → bool
-
no setter
- isNegativeAcknowledgement → bool
-
no setter
- name → String
-
final
- raw → String
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
-
values
→ Map<
String, String> -
final
Methods
-
listValue(
String key) → List< String> - Parses a comma-separated protocol list value, honoring , and \ escaping from the Streaming Encoder Ethernet Protocol.
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited